clear; clc; warning off;
s = tf('s');

%% Double integrator in continuous time
A = [0 1; 0 0];
B = [0; 1];
C = [1, 0];
D = 0;

Cx = eye(size(A));
Dx = zeros(size(Cx,1),size(B,2));


x0 = [1;1];     % Initial condition

%% Discretization
h = 0.44;
[Phi,Gamma] = c2d(A,B,h);

%% Control design
% Desired poles in continuous time
omega = 1; zeta = sqrt(2)/2;
pc = roots([1 2*zeta*omega omega^2]);
% Corresponding desired discrete poles
pd = exp(pc*h);

% Design state feedback with pole placement
L = place(Phi,Gamma,pd);

%% Observer design
p_obs = [0.75 0.75];
K     = acker(Phi',C',p_obs)';


%% Define the matrices for the simulation
Aob = Phi-Gamma*L-K*C;
Bob = K;
Cob = eye(size(Aob));
Dob = zeros(size(Cob,1),size(Bob,2));

%% Simulation
tend = 50;
sim('L9_LandObs.slx');

%% Plotting results
figure(1); clf;
subplot(311);
hold on;
    plot(x.time,x.signals.values);
    stairs(t,xhat,'--');
    plot(x.time,zeros(size(x.time)),'k:');
hold off;
    xlabel('time [s]');
    ylabel('States x');
    ylim([min(y.signals.values)*1.2,max(y.signals.values)*1.2]);

subplot(312);
    stairs(t,u);
    xlabel('time [s]');
    ylabel('Input u');
    ylim([min(u)*1.2,max(u)*1.2]);
    
subplot(313);
hold on;
    plot(v.time,v.signals.values,'k--');
hold off;
    xlabel('time [s]');
    ylabel('Disturbance v');
    ylim([min(v.signals.values)*1.2,max(v.signals.values)*1.2]);
    
figure(2); clf;
hold on;
    plot(y.time,y.signals.values);
    plot(y.time,zeros(size(y.time)),'k:');
hold off;
    xlabel('time [s]');
    ylabel('Output y');
    ylim([min(y.signals.values)*1.2,max(y.signals.values)*1.2]);
    